@@ -4,6 +4,7 @@
 
 
 import os
+import stat
 import sys
 
 import static_ffmpeg
@@ -26,8 +27,11 @@ def main():
     """Entry point for running static_ffmpeg, which delegates to ffmpeg."""
     ffmpeg_exe = get_platform_executable_or_raise()
     str_args = " ".join(sys.argv[1:])
-    if os.platform != 'win32':
-        assert os.access(ffmpeg_exe, os.X_OK)
+    if sys.platform != 'win32':
+        if not os.access(ffmpeg_exe, os.X_OK):
+            mode = stat.S_IXOTH | stat.S_IXUSR | stat.S_IXGRP
+            os.chmod(ffmpeg_exe, mode)
+            assert os.access(ffmpeg_exe, os.X_OK), f'Could not execute {ffmpeg_exe}'
     cmd = f"{ffmpeg_exe} {str_args}"
     rtn = os.system(cmd)
     sys.exit(rtn)
